@@ -1,4 +1,5 @@
 import os
+
 import boto3
 
 __all__ = [
@@ -6,6 +7,7 @@ __all__ = [
     "attach_s3_bucket",
 ]
 
+
 def upload_directory_to_s3(path, bucket, prefix, verbose=False):
     path = str(path)
     prefix = str(prefix)
@@ -15,9 +17,10 @@ def upload_directory_to_s3(path, bucket, prefix, verbose=False):
             src = os.path.join(subdir, f)
             dst = os.path.join(pfx, f)
             if verbose:
-                print(f'{src}  -->  {dst}')
+                print(f"{src}  -->  {dst}")
             bucket.upload_file(src, dst)
 
+
 def attach_s3_bucket(env_var_prefix):
     s3 = boto3.resource(
         service_name="s3",
@@ -26,4 +29,3 @@ def attach_s3_bucket(env_var_prefix):
         aws_secret_access_key=os.environ[f"{env_var_prefix}_SECRET_KEY"],
     )
     return s3.Bucket(os.environ[f"{env_var_prefix}_BUCKET"])
-
