@@ -1,4 +1,6 @@
+import math
 import os
+from datetime import datetime
 
 import trino
 from sqlalchemy.engine import create_engine
@@ -90,11 +92,22 @@ class TrinoBatchInsert(object):
 
     @staticmethod
     def _sqlform(x):
+        if x is None:
+            return "NULL"
         if isinstance(x, str):
             # escape any single quotes in the string
             t = x.replace("'", "''")
             # enclose string with single quotes
             return f"'{t}'"
+        if isinstance(x, datetime):
+            return f"TIMESTAMP '{x}'"
+        if isinstance(x, float):
+            if math.isnan(x):
+                return "nan()"
+            if math.isinf(x):
+                if x < 0:
+                    return "-infinity()"
+                return "infinity()"
         return str(x)
 
     @staticmethod
